summaryrefslogtreecommitdiffstats
path: root/dozentenmodul/src/main/java/org/openslx/dozmod/authentication/ShibbolethEcp.java
diff options
context:
space:
mode:
Diffstat (limited to 'dozentenmodul/src/main/java/org/openslx/dozmod/authentication/ShibbolethEcp.java')
-rw-r--r--dozentenmodul/src/main/java/org/openslx/dozmod/authentication/ShibbolethEcp.java9
1 files changed, 5 insertions, 4 deletions
diff --git a/dozentenmodul/src/main/java/org/openslx/dozmod/authentication/ShibbolethEcp.java b/dozentenmodul/src/main/java/org/openslx/dozmod/authentication/ShibbolethEcp.java
index ce8bbe95..071b92ad 100644
--- a/dozentenmodul/src/main/java/org/openslx/dozmod/authentication/ShibbolethEcp.java
+++ b/dozentenmodul/src/main/java/org/openslx/dozmod/authentication/ShibbolethEcp.java
@@ -13,6 +13,7 @@ import org.apache.http.util.EntityUtils;
import org.apache.log4j.Logger;
import org.openslx.bwlp.thrift.iface.AuthorizationError;
import org.openslx.bwlp.thrift.iface.TAuthorizationException;
+import org.openslx.dozmod.Branding;
import org.openslx.dozmod.util.ProxyConfigurator;
import com.google.gson.Gson;
@@ -39,7 +40,7 @@ public class ShibbolethEcp {
*/
private static ServiceProviderResponse lastResponse = null;
/**
* URL for bwLehrpool registration
*/
private static URL registrationUrl = null;
@@ -51,7 +52,7 @@ public class ShibbolethEcp {
NO_ERROR(0,
"Authentication against the identity provider and request of the service provider resource worked."),
IDENTITY_PROVIDER_ERROR(1, "Authentication against the identity provider failed."),
- UNREGISTERED_ERROR(2, "User not registered to use bwLehrpool."),
+ UNREGISTERED_ERROR(2, "User not registered to use " + Branding.getServiceName() + "."),
SERVICE_PROVIDER_ERROR(3, "Invalid resource of the service provider."),
INVALID_URL_ERROR(4, "Invalid URL received from master server."),
GENERIC_ERROR(5, "Internal error.");
@@ -80,7 +81,7 @@ public class ShibbolethEcp {
static {
URI tmp;
try {
- tmp = new URI("https://bwlp-masterserver.ruf.uni-freiburg.de/webif/shib/api.php");
+ tmp = new URI("https://" + Branding.getMasterServerAddress() + "/webif/shib/api.php");
} catch (URISyntaxException e) {
// should never happen!
LOGGER.error("Bad URI syntax of the service provider, see trace: ", e);
@@ -171,7 +172,7 @@ public class ShibbolethEcp {
}
if (lastResponse.status.equals("anonymous")) {
LOGGER.error("IdP did not forward user account information to SP. Contact developer.");
- lastResponse.error = "Ihr Identity-Provider hat dem bwLehrpool-System Ihre E-Mail oder Ihren Namen nicht mitgeteilt";
+ lastResponse.error = "Ihr Identity-Provider hat dem " + Branding.getServiceName() + "-System Ihre E-Mail oder Ihren Namen nicht mitgeteilt";
return ReturnCode.GENERIC_ERROR;
}
if (lastResponse.status.equals("ok")) {
@@ -39,7 +40,7 @@ public class ShibbolethEcp {
private static ServiceProviderResponse lastResponse = null;
/**
- * URL for bwLehrpool registration
+ * URL for service registration
*/
private static URL registrationUrl = null;